==> haskell-bencode-0.6.0.0-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bencode
version: 0.6.0.0
id: bencode-0.6.0.0-FIXLTPCBYZWEaPBO44nrUm
key: bencode-0.6.0.0-FIXLTPCBYZWEaPBO44nrUm
license: BSD3
copyright: (c) 2005-2009, David Himmelstrup,
           2006 Lemmih <lemmih@gmail.com>,
           2005 Jesper Louis Andersen <jlouis@mongers.org>
maintainer: Christopher Reichert <creichert07@gmail.com>
synopsis: Parser and printer for bencoded data.
description:
    Parser and printer for bencoded data.
    .
    Bencode (pronounced like B encode) is the encoding used by the
    peer-to-peer file sharing system BitTorrent for storing and
    transmitting loosely structured data.
category: Text
author: Lemmih (lemmih@gmail.com), Jesper Louis Andersen
exposed: True
indefinite: False
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
abi: 2fb893601f48043df2a059f91eac9a76
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/bencode-0.6.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/bencode-0.6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/bencode-0.6.0.0
hs-libraries: HSbencode-0.6.0.0-FIXLTPCBYZWEaPBO44nrUm
depends:
    base-4.10.1.0 parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap
    bytestring-0.10.8.2 containers-0.5.10.2 binary-0.8.5.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap=e5bced146b6517b43ed5d06001479bde
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
haddock-interfaces: /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html: /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bencode-0.6.0.0-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bencode
version: 0.6.0.0
id: bencode-0.6.0.0-HjxHKkniC4T1KxAeGGP8Az
key: bencode-0.6.0.0-HjxHKkniC4T1KxAeGGP8Az
license: BSD3
copyright: (c) 2005-2009, David Himmelstrup,
           2006 Lemmih <lemmih@gmail.com>,
           2005 Jesper Louis Andersen <jlouis@mongers.org>
maintainer: Christopher Reichert <creichert07@gmail.com>
synopsis: Parser and printer for bencoded data.
description:
    Parser and printer for bencoded data.
    .
    Bencode (pronounced like B encode) is the encoding used by the
    peer-to-peer file sharing system BitTorrent for storing and
    transmitting loosely structured data.
category: Text
author: Lemmih (lemmih@gmail.com), Jesper Louis Andersen
exposed: True
indefinite: False
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
abi: 8ffd93c2978fdc24f5b10c5f4bcc8feb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/bencode-0.6.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/bencode-0.6.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/bencode-0.6.0.0
hs-libraries: HSbencode-0.6.0.0-HjxHKkniC4T1KxAeGGP8Az
depends:
    base-4.10.1.0 parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
    bytestring-0.10.8.2 containers-0.5.10.2 binary-0.8.5.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
haddock-interfaces: /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html: /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
